@@ -2,5 +2,5 @@
 A package containing multiple general use utilities for free use.
 """
 __author__ = 'Taylor "Nekroze" Lawson'
-__email__ = 'nekroze@eturnilnetwork.com'
-__version__ = '0.4.0'
+__email__ = 'tlawson@nekroze.com'
+__version__ = '0.5.0'
