@@ -32,7 +32,7 @@ def tree_add(tree, path, key, leaf):
     """
     branch = tree
     for item in path:
-        if not item in branch:
+        if item not in branch:
             branch[item] = {}
         branch = branch[item]
 
